use rustracing_jaeger::Span;
use tiny_http::{Request, ResponseBox};

use crate::{
    db::DBConnection,
    dto,
    routes::{filters::UserInfo, get_reply},
    AppError
};

pub fn info(_: &Span, _: &mut Request, _: &mut DBConnection, info: UserInfo) -> Result<ResponseBox, AppError> {
    get_reply(&dto::responses::UserInfo {
        statusCode: info.0.id,
        name: info.0.name,
        gitlab: info.0.gitlab,
        tfaEnabled: info.0.tfa_type != crate::db::TfaTypes::None
    })
}

pub fn delete_user(
    span: &Span,
    _: &mut Request,
    db: &mut DBConnection,
    info: UserInfo
) -> Result<ResponseBox, AppError> {
    db.delete_all_tokens(span, info.0.id);

    let root_node = super::fs::get_node_and_validate(span, &info.0, info.0.root_id, db)
        .expect("Failed to get root node for deleting");

    super::fs::delete_node_root(span, &root_node, db);

    db.delete_user(&info.0);

    get_reply(&dto::responses::Success { statusCode: 200 })
}
